@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,10 +50,11 @@
 package com.openexchange.threadpool.internal;
 
 import java.util.concurrent.atomic.AtomicInteger;
+import com.openexchange.log.LogProperties;
 
 /**
  * {@link CustomThreadFactory} - A thread factory taking a custom name prefix for created threads.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class CustomThreadFactory implements java.util.concurrent.ThreadFactory {
@@ -68,14 +69,14 @@ public final class CustomThreadFactory implements java.util.concurrent.ThreadFac
 
     /**
      * Initializes a new {@link CustomThreadFactory}.
-     * 
+     *
      * @param namePrefix The name prefix
      */
     public CustomThreadFactory(final String namePrefix) {
         super();
         threadNumber = new AtomicInteger();
         this.namePrefix = namePrefix;
-        this.len = namePrefix.length() + 7;
+        len = namePrefix.length() + 7;
     }
 
     public Thread newThread(final Runnable r) {
@@ -100,7 +101,7 @@ public final class CustomThreadFactory implements java.util.concurrent.ThreadFac
         /*-
          * Previous approach which could possibly result in an infinite cycle
          * when two threads enter the loop simultaneously
-         * 
+         *
         while (threadNum <= 0) {
             if (threadNumber.compareAndSet(threadNum, 1)) {
                 threadNum = 1;
@@ -114,6 +115,7 @@ public final class CustomThreadFactory implements java.util.concurrent.ThreadFac
          */
         final CustomThread t = new CustomThread(r, getThreadName(threadNum, new StringBuilder(len).append(namePrefix)));
         t.setUncaughtExceptionHandler(new CustomUncaughtExceptionhandler());
+        LogProperties.cloneLogProperties(t);
         return t;
     }
 
