@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,7 +53,7 @@ import java.util.concurrent.BlockingQueue;
 
 /**
  * {@link QueueType} - The queue type.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public enum QueueType {
@@ -61,7 +61,7 @@ public enum QueueType {
     /**
      * Synchronous queue type.
      */
-    SYNCHRONOUS("synchronous", new IQueueProvider() {
+    SYNCHRONOUS("synchronous", false, new IQueueProvider() {
 
         public BlockingQueue<Runnable> newWorkQueue(final int fixedCapacity) {
             return QueueProvider.getInstance().newSynchronousQueue();
@@ -70,7 +70,7 @@ public enum QueueType {
     /**
      * Linked queue type.
      */
-    LINKED("linked", new IQueueProvider() {
+    LINKED("linked", true, new IQueueProvider() {
 
         public BlockingQueue<Runnable> newWorkQueue(final int fixedCapacity) {
             return QueueProvider.getInstance().newLinkedQueue(fixedCapacity);
@@ -81,14 +81,31 @@ public enum QueueType {
 
     private final IQueueProvider queueProvider;
 
-    private QueueType(final String type, final IQueueProvider queueProvider) {
+    private final boolean fixedSize;
+
+    private QueueType(final String type, final boolean fixedSize, final IQueueProvider queueProvider) {
+        this.fixedSize = fixedSize;
         this.type = type;
         this.queueProvider = queueProvider;
     }
 
+
+    /**
+     * Checks whether the queue type enforces the thread pool being at fixed-size.
+     * <ul>
+     * <li>A <b>synchronous</b> queue is appropriate for <code>core-size &lt; max-size</code></li>
+     * <li>A <b>linked</b> queue is appropriate for <code>core-size = max-size</code></li>
+     * </ul>
+     *
+     * @return <code>true</code> if the queue type enforces the thread pool being at fixed-size; otherwsie <code>false</code>
+     */
+    public boolean isFixedSize() {
+        return fixedSize;
+    }
+
     /**
      * Creates a new work queue of this type.
-     * 
+     *
      * @param fixedCapacity The fixed capacity
      * @return A new work queue of this type
      */
@@ -98,7 +115,7 @@ public enum QueueType {
 
     /**
      * Gets the queue type for given type string.
-     * 
+     *
      * @param type The type string
      * @return The queue type for given type string or <code>null</code>
      */
