@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -62,7 +62,7 @@ import com.openexchange.threadpool.internal.ThreadPoolInformation;
 
 /**
  * {@link ManagementServiceTrackerCustomizer} - The {@link ServiceTrackerCustomizer customizer} for {@link ManagementService}.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ManagementServiceTrackerCustomizer implements ServiceTrackerCustomizer {
@@ -75,7 +75,7 @@ public final class ManagementServiceTrackerCustomizer implements ServiceTrackerC
 
     /**
      * Initializes a new {@link ManagementServiceTrackerCustomizer}.
-     * 
+     *
      * @param context The bundle context
      * @param threadPoolService The thread pool service previously registered
      */
@@ -118,7 +118,7 @@ public final class ManagementServiceTrackerCustomizer implements ServiceTrackerC
     void registerCacheMBean(final ManagementService management) {
         if (objectName == null) {
             final org.apache.commons.logging.Log LOG =
-                org.apache.commons.logging.LogFactory.getLog(ManagementServiceTrackerCustomizer.class);
+                com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(ManagementServiceTrackerCustomizer.class));
             try {
                 objectName = getObjectName(ThreadPoolInformation.class.getName(), ThreadPoolInformationMBean.THREAD_POOL_DOMAIN);
                 management.registerMBean(objectName, new ThreadPoolInformation(threadPoolService));
@@ -137,7 +137,7 @@ public final class ManagementServiceTrackerCustomizer implements ServiceTrackerC
             try {
                 management.unregisterMBean(objectName);
             } catch (final Exception e) {
-                org.apache.commons.logging.LogFactory.getLog(ManagementServiceTrackerCustomizer.class).error(e.getMessage(), e);
+                com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(ManagementServiceTrackerCustomizer.class)).error(e.getMessage(), e);
             } finally {
                 objectName = null;
             }
@@ -146,7 +146,7 @@ public final class ManagementServiceTrackerCustomizer implements ServiceTrackerC
 
     /**
      * Creates an appropriate instance of {@link ObjectName} from specified class name and domain name.
-     * 
+     *
      * @param className The class name to use as object name
      * @param domain The domain name
      * @return An appropriate instance of {@link ObjectName}
